@@ -4,7 +4,8 @@ from django.db import models
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from django.utils.translation import ugettext as _
-from utils import create_model
+from miniature.models.fields import AutoSlugField
+from miniature.models.utils import create_model
 
 __author__ = 'ir4y'
 
@@ -67,20 +68,11 @@ def SlugTraits(base_filed_name='name'):
     """
     fileld_name = base_filed_name + '_slug'
     fields = {
-        fileld_name: models.SlugField(verbose_name=_(u'Название для url'),
-                                      max_length=150, blank=True, null=True)
+        fileld_name: AutoSlugField(verbose_name=_(u'Название для url'),
+                                   populate_from='{' + base_filed_name + '}',
+                                   max_length=150, blank=True, null=True)
     }
-    _SlugMixin = create_model('SlugMixin', fields=fields, module='main.models',
+    _SlugMixin = create_model('SlugMixin', fields=fields,
+                              module='miniature.models.mixins',
                               options={'abstract': True})
-
-    def save(self, **kwargs):
-        """
-        Перегружаем оператор save
-        При сохранении записываем slug от указанного поля в новое поле
-        """
-        original_text = getattr(self, base_filed_name)
-        slug_text = pytils.translit.slugify(original_text)[:150]
-        setattr(self, fileld_name, slug_text)
-        return super(_SlugMixin, self).save(**kwargs)
-    setattr(_SlugMixin, 'save', save)
     return _SlugMixin
